# Generated by Django 3.2.23 on 2023-11-28 14:36

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailcore', '0066_collection_management_permissions'),
        ('coyote', '0010_auto_20231127_1018'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='ColorSetting',
            new_name='StyleSettings',
        ),
    ]
