.persons-block{
	@extend .coyote-block-wrapper;
	.person{
		position: relative;
		min-height: 480px;
		z-index: 3;
		overflow: hidden;
		.person-image{
			transform-style: preserve-3d;
			transition: 3s cubic-bezier(.3,1,.3,1);
			@media screen and (min-width: 991px){
				transform: scale(1.1) translateZ(0);
			}
			img{
				border-radius: 0;
				color: var(--primary);
				object-fit: cover;
				height: 480px;
				z-index: 1;
			}
		}
		.info-block{
			-webkit-backdrop-filter: blur(23px);
			backdrop-filter: blur(23px);
			background-color: rgba(255, 255, 255, .3);
			flex-direction: column;
			justify-content: flex-start;
			align-items: flex-start;
			display: flex;
			position: absolute;
			bottom: 0%;
			left: 0%;
			right: 0%;
			will-change: transform;
			transform-style: preserve-3d;
			transition: 1s cubic-bezier(.3,1,.3,1);
			z-index: 3;
			max-height: 140px;
			.info-block-inner{
				padding: 1rem 1.5rem;
			}
			h5{
				font-weight: 400 !important;
			}
			*{
				color: white;
			}
		}
		&:not(:hover){
			@media screen and (min-width: 991px){
				.info-block{
					max-height: 0;
				}
				.person-image{
					transform: scale(1);
				}
			}
		}
	}
}