# Generated by Django 3.2.20 on 2023-09-07 10:00

from django.db import migrations, models
import django.db.models.deletion
import wagtail.blocks
import wagtail.fields
import wagtail.images.blocks


class Migration(migrations.Migration):
    dependencies = [
        ("wagtailcore", "0066_collection_management_permissions"),
        ("coyote", "0002_auto_20230831_1631"),
    ]

    operations = [
        migrations.CreateModel(
            name="CoyoteContactPage",
            fields=[
                (
                    "page_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to="wagtailcore.page",
                    ),
                ),
                (
                    "header",
                    wagtail.fields.StreamField(
                        [
                            (
                                "Foto",
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            "body",
                                            wagtail.blocks.RichTextBlock(
                                                label="Inhoud", required=True
                                            ),
                                        ),
                                        (
                                            "buttons",
                                            wagtail.blocks.ListBlock(
                                                wagtail.blocks.StructBlock(
                                                    [
                                                        (
                                                            "label",
                                                            wagtail.blocks.CharBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "page_url",
                                                            wagtail.blocks.PageChooserBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "external_url",
                                                            wagtail.blocks.CharBlock(
                                                                help_text="You can also use the mailto: or tel: preset for functional use",
                                                                label="External url",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "new_tab",
                                                            wagtail.blocks.BooleanBlock(
                                                                default=False,
                                                                label="Open in new tab",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "button_style",
                                                            wagtail.blocks.ChoiceBlock(
                                                                choices=[
                                                                    (
                                                                        "primary",
                                                                        "Primary",
                                                                    ),
                                                                    (
                                                                        "secondary",
                                                                        "Secondary",
                                                                    ),
                                                                    ("light", "Light"),
                                                                    ("dark", "Dark"),
                                                                    ("info", "Info"),
                                                                    (
                                                                        "success",
                                                                        "Success",
                                                                    ),
                                                                    (
                                                                        "warning",
                                                                        "Warning",
                                                                    ),
                                                                    (
                                                                        "danger",
                                                                        "Danger",
                                                                    ),
                                                                ],
                                                                label="Button style",
                                                                required=False,
                                                            ),
                                                        ),
                                                    ]
                                                ),
                                                label="Buttons",
                                                required=False,
                                            ),
                                        ),
                                        (
                                            "image",
                                            wagtail.images.blocks.ImageChooserBlock(
                                                label="Afbeelding"
                                            ),
                                        ),
                                        (
                                            "overlay",
                                            wagtail.blocks.BooleanBlock(
                                                label="Dark overlay", required=False
                                            ),
                                        ),
                                        (
                                            "center_text",
                                            wagtail.blocks.BooleanBlock(
                                                label="Center the body", required=False
                                            ),
                                        ),
                                    ]
                                ),
                            ),
                            (
                                "Video",
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            "body",
                                            wagtail.blocks.RichTextBlock(
                                                label="Inhoud", required=True
                                            ),
                                        ),
                                        (
                                            "buttons",
                                            wagtail.blocks.ListBlock(
                                                wagtail.blocks.StructBlock(
                                                    [
                                                        (
                                                            "label",
                                                            wagtail.blocks.CharBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "page_url",
                                                            wagtail.blocks.PageChooserBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "external_url",
                                                            wagtail.blocks.CharBlock(
                                                                help_text="You can also use the mailto: or tel: preset for functional use",
                                                                label="External url",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "new_tab",
                                                            wagtail.blocks.BooleanBlock(
                                                                default=False,
                                                                label="Open in new tab",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "button_style",
                                                            wagtail.blocks.ChoiceBlock(
                                                                choices=[
                                                                    (
                                                                        "primary",
                                                                        "Primary",
                                                                    ),
                                                                    (
                                                                        "secondary",
                                                                        "Secondary",
                                                                    ),
                                                                    ("light", "Light"),
                                                                    ("dark", "Dark"),
                                                                    ("info", "Info"),
                                                                    (
                                                                        "success",
                                                                        "Success",
                                                                    ),
                                                                    (
                                                                        "warning",
                                                                        "Warning",
                                                                    ),
                                                                    (
                                                                        "danger",
                                                                        "Danger",
                                                                    ),
                                                                ],
                                                                label="Button style",
                                                                required=False,
                                                            ),
                                                        ),
                                                    ]
                                                ),
                                                label="Buttons",
                                                required=False,
                                            ),
                                        ),
                                        (
                                            "video",
                                            wagtail.blocks.CharBlock(
                                                label="Video", required=False
                                            ),
                                        ),
                                        (
                                            "position",
                                            wagtail.blocks.ChoiceBlock(
                                                choices=[
                                                    ("full-screen", "Achtergrond"),
                                                    ("media-side", "Next to content"),
                                                ],
                                                label="Postion of the media",
                                                required=False,
                                            ),
                                        ),
                                        (
                                            "overlay",
                                            wagtail.blocks.BooleanBlock(
                                                label="Dark overlay", required=False
                                            ),
                                        ),
                                    ]
                                ),
                            ),
                            (
                                "Content",
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            "body",
                                            wagtail.blocks.RichTextBlock(
                                                label="Inhoud", required=True
                                            ),
                                        ),
                                        (
                                            "buttons",
                                            wagtail.blocks.ListBlock(
                                                wagtail.blocks.StructBlock(
                                                    [
                                                        (
                                                            "label",
                                                            wagtail.blocks.CharBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "page_url",
                                                            wagtail.blocks.PageChooserBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "external_url",
                                                            wagtail.blocks.CharBlock(
                                                                help_text="You can also use the mailto: or tel: preset for functional use",
                                                                label="External url",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "new_tab",
                                                            wagtail.blocks.BooleanBlock(
                                                                default=False,
                                                                label="Open in new tab",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "button_style",
                                                            wagtail.blocks.ChoiceBlock(
                                                                choices=[
                                                                    (
                                                                        "primary",
                                                                        "Primary",
                                                                    ),
                                                                    (
                                                                        "secondary",
                                                                        "Secondary",
                                                                    ),
                                                                    ("light", "Light"),
                                                                    ("dark", "Dark"),
                                                                    ("info", "Info"),
                                                                    (
                                                                        "success",
                                                                        "Success",
                                                                    ),
                                                                    (
                                                                        "warning",
                                                                        "Warning",
                                                                    ),
                                                                    (
                                                                        "danger",
                                                                        "Danger",
                                                                    ),
                                                                ],
                                                                label="Button style",
                                                                required=False,
                                                            ),
                                                        ),
                                                    ]
                                                ),
                                                label="Buttons",
                                                required=False,
                                            ),
                                        ),
                                        (
                                            "image",
                                            wagtail.images.blocks.ImageChooserBlock(
                                                label="Afbeelding"
                                            ),
                                        ),
                                        (
                                            "position",
                                            wagtail.blocks.ChoiceBlock(
                                                choices=[
                                                    ("left", "Links"),
                                                    ("right", "Rechts"),
                                                ],
                                                label="Postion of the image",
                                                required=False,
                                            ),
                                        ),
                                    ]
                                ),
                            ),
                        ],
                        blank=True,
                        verbose_name="Header",
                    ),
                ),
                (
                    "content",
                    wagtail.fields.StreamField(
                        [
                            (
                                "Afbeelding_met_tekst",
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            "body",
                                            wagtail.blocks.RichTextBlock(
                                                label="Inhoud", required=True
                                            ),
                                        ),
                                        (
                                            "buttons",
                                            wagtail.blocks.ListBlock(
                                                wagtail.blocks.StructBlock(
                                                    [
                                                        (
                                                            "label",
                                                            wagtail.blocks.CharBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "page_url",
                                                            wagtail.blocks.PageChooserBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "external_url",
                                                            wagtail.blocks.CharBlock(
                                                                help_text="You can also use the mailto: or tel: preset for functional use",
                                                                label="External url",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "new_tab",
                                                            wagtail.blocks.BooleanBlock(
                                                                default=False,
                                                                label="Open in new tab",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "button_style",
                                                            wagtail.blocks.ChoiceBlock(
                                                                choices=[
                                                                    (
                                                                        "primary",
                                                                        "Primary",
                                                                    ),
                                                                    (
                                                                        "secondary",
                                                                        "Secondary",
                                                                    ),
                                                                    ("light", "Light"),
                                                                    ("dark", "Dark"),
                                                                    ("info", "Info"),
                                                                    (
                                                                        "success",
                                                                        "Success",
                                                                    ),
                                                                    (
                                                                        "warning",
                                                                        "Warning",
                                                                    ),
                                                                    (
                                                                        "danger",
                                                                        "Danger",
                                                                    ),
                                                                ],
                                                                label="Button style",
                                                                required=False,
                                                            ),
                                                        ),
                                                    ]
                                                ),
                                                label="Buttons",
                                                required=False,
                                            ),
                                        ),
                                        (
                                            "image",
                                            wagtail.images.blocks.ImageChooserBlock(
                                                label="Afbeelding"
                                            ),
                                        ),
                                        (
                                            "overlay",
                                            wagtail.blocks.BooleanBlock(
                                                label="Dark overlay", required=False
                                            ),
                                        ),
                                        (
                                            "center_text",
                                            wagtail.blocks.BooleanBlock(
                                                label="Center the body", required=False
                                            ),
                                        ),
                                    ],
                                    icon="image",
                                ),
                            ),
                            (
                                "Iconen_met_tekst",
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            "layout",
                                            wagtail.blocks.ChoiceBlock(
                                                choices=[
                                                    (
                                                        "layout1",
                                                        "coyote/layouts/icon_layout_1.svg",
                                                    ),
                                                    (
                                                        "layout2",
                                                        "coyote/layouts/icon_layout_2.svg",
                                                    ),
                                                ]
                                            ),
                                        ),
                                        (
                                            "body",
                                            wagtail.blocks.RichTextBlock(
                                                label="Inhoud", required=True
                                            ),
                                        ),
                                        (
                                            "icons",
                                            wagtail.blocks.ListBlock(
                                                wagtail.blocks.StructBlock(
                                                    [
                                                        (
                                                            "icon",
                                                            wagtail.blocks.CharBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "header",
                                                            wagtail.blocks.CharBlock(
                                                                label="Header",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "body",
                                                            wagtail.blocks.TextBlock(
                                                                label="Short text",
                                                                max_length=100,
                                                                required=True,
                                                            ),
                                                        ),
                                                    ]
                                                ),
                                                label="Text Block",
                                                required=False,
                                            ),
                                        ),
                                        (
                                            "button",
                                            wagtail.blocks.StructBlock(
                                                [
                                                    (
                                                        "label",
                                                        wagtail.blocks.CharBlock(
                                                            required=False
                                                        ),
                                                    ),
                                                    (
                                                        "page_url",
                                                        wagtail.blocks.PageChooserBlock(
                                                            required=False
                                                        ),
                                                    ),
                                                    (
                                                        "external_url",
                                                        wagtail.blocks.CharBlock(
                                                            help_text="You can also use the mailto: or tel: preset for functional use",
                                                            label="External url",
                                                            required=False,
                                                        ),
                                                    ),
                                                    (
                                                        "new_tab",
                                                        wagtail.blocks.BooleanBlock(
                                                            default=False,
                                                            label="Open in new tab",
                                                            required=False,
                                                        ),
                                                    ),
                                                    (
                                                        "button_style",
                                                        wagtail.blocks.ChoiceBlock(
                                                            choices=[
                                                                ("primary", "Primary"),
                                                                (
                                                                    "secondary",
                                                                    "Secondary",
                                                                ),
                                                                ("light", "Light"),
                                                                ("dark", "Dark"),
                                                                ("info", "Info"),
                                                                ("success", "Success"),
                                                                ("warning", "Warning"),
                                                                ("danger", "Danger"),
                                                            ],
                                                            label="Button style",
                                                            required=False,
                                                        ),
                                                    ),
                                                ],
                                                required=False,
                                            ),
                                        ),
                                    ],
                                    icon="info-circle",
                                ),
                            ),
                            (
                                "Center_tekts",
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            "body",
                                            wagtail.blocks.RichTextBlock(
                                                label="Inhoud", required=True
                                            ),
                                        ),
                                        (
                                            "buttons",
                                            wagtail.blocks.ListBlock(
                                                wagtail.blocks.StructBlock(
                                                    [
                                                        (
                                                            "label",
                                                            wagtail.blocks.CharBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "page_url",
                                                            wagtail.blocks.PageChooserBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "external_url",
                                                            wagtail.blocks.CharBlock(
                                                                help_text="You can also use the mailto: or tel: preset for functional use",
                                                                label="External url",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "new_tab",
                                                            wagtail.blocks.BooleanBlock(
                                                                default=False,
                                                                label="Open in new tab",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "button_style",
                                                            wagtail.blocks.ChoiceBlock(
                                                                choices=[
                                                                    (
                                                                        "primary",
                                                                        "Primary",
                                                                    ),
                                                                    (
                                                                        "secondary",
                                                                        "Secondary",
                                                                    ),
                                                                    ("light", "Light"),
                                                                    ("dark", "Dark"),
                                                                    ("info", "Info"),
                                                                    (
                                                                        "success",
                                                                        "Success",
                                                                    ),
                                                                    (
                                                                        "warning",
                                                                        "Warning",
                                                                    ),
                                                                    (
                                                                        "danger",
                                                                        "Danger",
                                                                    ),
                                                                ],
                                                                label="Button style",
                                                                required=False,
                                                            ),
                                                        ),
                                                    ]
                                                ),
                                                label="Buttons",
                                                required=False,
                                            ),
                                        ),
                                        (
                                            "image",
                                            wagtail.images.blocks.ImageChooserBlock(
                                                label="Afbeelding"
                                            ),
                                        ),
                                        (
                                            "overlay",
                                            wagtail.blocks.BooleanBlock(
                                                label="Dark overlay", required=False
                                            ),
                                        ),
                                        (
                                            "center_text",
                                            wagtail.blocks.BooleanBlock(
                                                label="Center the body", required=False
                                            ),
                                        ),
                                    ],
                                    icon="collapse-down",
                                ),
                            ),
                            (
                                "Logos",
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            "logos",
                                            wagtail.blocks.ListBlock(
                                                wagtail.images.blocks.ImageChooserBlock(),
                                                required=False,
                                            ),
                                        )
                                    ],
                                    icon="tag",
                                ),
                            ),
                            (
                                "Quotes",
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            "body",
                                            wagtail.blocks.RichTextBlock(
                                                label="Inhoud", required=True
                                            ),
                                        ),
                                        (
                                            "buttons",
                                            wagtail.blocks.ListBlock(
                                                wagtail.blocks.StructBlock(
                                                    [
                                                        (
                                                            "label",
                                                            wagtail.blocks.CharBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "page_url",
                                                            wagtail.blocks.PageChooserBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "external_url",
                                                            wagtail.blocks.CharBlock(
                                                                help_text="You can also use the mailto: or tel: preset for functional use",
                                                                label="External url",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "new_tab",
                                                            wagtail.blocks.BooleanBlock(
                                                                default=False,
                                                                label="Open in new tab",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "button_style",
                                                            wagtail.blocks.ChoiceBlock(
                                                                choices=[
                                                                    (
                                                                        "primary",
                                                                        "Primary",
                                                                    ),
                                                                    (
                                                                        "secondary",
                                                                        "Secondary",
                                                                    ),
                                                                    ("light", "Light"),
                                                                    ("dark", "Dark"),
                                                                    ("info", "Info"),
                                                                    (
                                                                        "success",
                                                                        "Success",
                                                                    ),
                                                                    (
                                                                        "warning",
                                                                        "Warning",
                                                                    ),
                                                                    (
                                                                        "danger",
                                                                        "Danger",
                                                                    ),
                                                                ],
                                                                label="Button style",
                                                                required=False,
                                                            ),
                                                        ),
                                                    ]
                                                ),
                                                label="Buttons",
                                                required=False,
                                            ),
                                        ),
                                        (
                                            "image",
                                            wagtail.images.blocks.ImageChooserBlock(
                                                label="Afbeelding"
                                            ),
                                        ),
                                        (
                                            "overlay",
                                            wagtail.blocks.BooleanBlock(
                                                label="Dark overlay", required=False
                                            ),
                                        ),
                                        (
                                            "center_text",
                                            wagtail.blocks.BooleanBlock(
                                                label="Center the body", required=False
                                            ),
                                        ),
                                    ],
                                    icon="openquote",
                                ),
                            ),
                            (
                                "Jumbotron",
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            "body",
                                            wagtail.blocks.RichTextBlock(
                                                label="Inhoud", required=True
                                            ),
                                        ),
                                        (
                                            "buttons",
                                            wagtail.blocks.ListBlock(
                                                wagtail.blocks.StructBlock(
                                                    [
                                                        (
                                                            "label",
                                                            wagtail.blocks.CharBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "page_url",
                                                            wagtail.blocks.PageChooserBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "external_url",
                                                            wagtail.blocks.CharBlock(
                                                                help_text="You can also use the mailto: or tel: preset for functional use",
                                                                label="External url",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "new_tab",
                                                            wagtail.blocks.BooleanBlock(
                                                                default=False,
                                                                label="Open in new tab",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "button_style",
                                                            wagtail.blocks.ChoiceBlock(
                                                                choices=[
                                                                    (
                                                                        "primary",
                                                                        "Primary",
                                                                    ),
                                                                    (
                                                                        "secondary",
                                                                        "Secondary",
                                                                    ),
                                                                    ("light", "Light"),
                                                                    ("dark", "Dark"),
                                                                    ("info", "Info"),
                                                                    (
                                                                        "success",
                                                                        "Success",
                                                                    ),
                                                                    (
                                                                        "warning",
                                                                        "Warning",
                                                                    ),
                                                                    (
                                                                        "danger",
                                                                        "Danger",
                                                                    ),
                                                                ],
                                                                label="Button style",
                                                                required=False,
                                                            ),
                                                        ),
                                                    ]
                                                ),
                                                label="Buttons",
                                                required=False,
                                            ),
                                        ),
                                        (
                                            "image",
                                            wagtail.images.blocks.ImageChooserBlock(
                                                label="Afbeelding"
                                            ),
                                        ),
                                        (
                                            "overlay",
                                            wagtail.blocks.BooleanBlock(
                                                label="Dark overlay", required=False
                                            ),
                                        ),
                                        (
                                            "center_text",
                                            wagtail.blocks.BooleanBlock(
                                                label="Center the body", required=False
                                            ),
                                        ),
                                    ],
                                    icon="form",
                                ),
                            ),
                            (
                                "Accordeon",
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            "body",
                                            wagtail.blocks.RichTextBlock(
                                                label="Inhoud", required=True
                                            ),
                                        ),
                                        (
                                            "buttons",
                                            wagtail.blocks.ListBlock(
                                                wagtail.blocks.StructBlock(
                                                    [
                                                        (
                                                            "label",
                                                            wagtail.blocks.CharBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "page_url",
                                                            wagtail.blocks.PageChooserBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "external_url",
                                                            wagtail.blocks.CharBlock(
                                                                help_text="You can also use the mailto: or tel: preset for functional use",
                                                                label="External url",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "new_tab",
                                                            wagtail.blocks.BooleanBlock(
                                                                default=False,
                                                                label="Open in new tab",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "button_style",
                                                            wagtail.blocks.ChoiceBlock(
                                                                choices=[
                                                                    (
                                                                        "primary",
                                                                        "Primary",
                                                                    ),
                                                                    (
                                                                        "secondary",
                                                                        "Secondary",
                                                                    ),
                                                                    ("light", "Light"),
                                                                    ("dark", "Dark"),
                                                                    ("info", "Info"),
                                                                    (
                                                                        "success",
                                                                        "Success",
                                                                    ),
                                                                    (
                                                                        "warning",
                                                                        "Warning",
                                                                    ),
                                                                    (
                                                                        "danger",
                                                                        "Danger",
                                                                    ),
                                                                ],
                                                                label="Button style",
                                                                required=False,
                                                            ),
                                                        ),
                                                    ]
                                                ),
                                                label="Buttons",
                                                required=False,
                                            ),
                                        ),
                                        (
                                            "image",
                                            wagtail.images.blocks.ImageChooserBlock(
                                                label="Afbeelding"
                                            ),
                                        ),
                                        (
                                            "overlay",
                                            wagtail.blocks.BooleanBlock(
                                                label="Dark overlay", required=False
                                            ),
                                        ),
                                        (
                                            "center_text",
                                            wagtail.blocks.BooleanBlock(
                                                label="Center the body", required=False
                                            ),
                                        ),
                                    ],
                                    icon="list-ul",
                                ),
                            ),
                            (
                                "Producten",
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            "body",
                                            wagtail.blocks.RichTextBlock(
                                                label="Inhoud", required=True
                                            ),
                                        ),
                                        (
                                            "buttons",
                                            wagtail.blocks.ListBlock(
                                                wagtail.blocks.StructBlock(
                                                    [
                                                        (
                                                            "label",
                                                            wagtail.blocks.CharBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "page_url",
                                                            wagtail.blocks.PageChooserBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "external_url",
                                                            wagtail.blocks.CharBlock(
                                                                help_text="You can also use the mailto: or tel: preset for functional use",
                                                                label="External url",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "new_tab",
                                                            wagtail.blocks.BooleanBlock(
                                                                default=False,
                                                                label="Open in new tab",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "button_style",
                                                            wagtail.blocks.ChoiceBlock(
                                                                choices=[
                                                                    (
                                                                        "primary",
                                                                        "Primary",
                                                                    ),
                                                                    (
                                                                        "secondary",
                                                                        "Secondary",
                                                                    ),
                                                                    ("light", "Light"),
                                                                    ("dark", "Dark"),
                                                                    ("info", "Info"),
                                                                    (
                                                                        "success",
                                                                        "Success",
                                                                    ),
                                                                    (
                                                                        "warning",
                                                                        "Warning",
                                                                    ),
                                                                    (
                                                                        "danger",
                                                                        "Danger",
                                                                    ),
                                                                ],
                                                                label="Button style",
                                                                required=False,
                                                            ),
                                                        ),
                                                    ]
                                                ),
                                                label="Buttons",
                                                required=False,
                                            ),
                                        ),
                                        (
                                            "image",
                                            wagtail.images.blocks.ImageChooserBlock(
                                                label="Afbeelding"
                                            ),
                                        ),
                                        (
                                            "overlay",
                                            wagtail.blocks.BooleanBlock(
                                                label="Dark overlay", required=False
                                            ),
                                        ),
                                        (
                                            "center_text",
                                            wagtail.blocks.BooleanBlock(
                                                label="Center the body", required=False
                                            ),
                                        ),
                                    ],
                                    icon="tag",
                                ),
                            ),
                            (
                                "Categorieen",
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            "body",
                                            wagtail.blocks.RichTextBlock(
                                                label="Inhoud", required=True
                                            ),
                                        ),
                                        (
                                            "buttons",
                                            wagtail.blocks.ListBlock(
                                                wagtail.blocks.StructBlock(
                                                    [
                                                        (
                                                            "label",
                                                            wagtail.blocks.CharBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "page_url",
                                                            wagtail.blocks.PageChooserBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "external_url",
                                                            wagtail.blocks.CharBlock(
                                                                help_text="You can also use the mailto: or tel: preset for functional use",
                                                                label="External url",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "new_tab",
                                                            wagtail.blocks.BooleanBlock(
                                                                default=False,
                                                                label="Open in new tab",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "button_style",
                                                            wagtail.blocks.ChoiceBlock(
                                                                choices=[
                                                                    (
                                                                        "primary",
                                                                        "Primary",
                                                                    ),
                                                                    (
                                                                        "secondary",
                                                                        "Secondary",
                                                                    ),
                                                                    ("light", "Light"),
                                                                    ("dark", "Dark"),
                                                                    ("info", "Info"),
                                                                    (
                                                                        "success",
                                                                        "Success",
                                                                    ),
                                                                    (
                                                                        "warning",
                                                                        "Warning",
                                                                    ),
                                                                    (
                                                                        "danger",
                                                                        "Danger",
                                                                    ),
                                                                ],
                                                                label="Button style",
                                                                required=False,
                                                            ),
                                                        ),
                                                    ]
                                                ),
                                                label="Buttons",
                                                required=False,
                                            ),
                                        ),
                                        (
                                            "image",
                                            wagtail.images.blocks.ImageChooserBlock(
                                                label="Afbeelding"
                                            ),
                                        ),
                                        (
                                            "overlay",
                                            wagtail.blocks.BooleanBlock(
                                                label="Dark overlay", required=False
                                            ),
                                        ),
                                        (
                                            "center_text",
                                            wagtail.blocks.BooleanBlock(
                                                label="Center the body", required=False
                                            ),
                                        ),
                                    ],
                                    icon="clipboard-list",
                                ),
                            ),
                        ],
                        blank=True,
                        verbose_name="Inhoud",
                    ),
                ),
                (
                    "footer",
                    wagtail.fields.StreamField(
                        [
                            (
                                "Call_To_Action",
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            "body",
                                            wagtail.blocks.RichTextBlock(
                                                label="Inhoud", required=True
                                            ),
                                        ),
                                        (
                                            "buttons",
                                            wagtail.blocks.ListBlock(
                                                wagtail.blocks.StructBlock(
                                                    [
                                                        (
                                                            "label",
                                                            wagtail.blocks.CharBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "page_url",
                                                            wagtail.blocks.PageChooserBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "external_url",
                                                            wagtail.blocks.CharBlock(
                                                                help_text="You can also use the mailto: or tel: preset for functional use",
                                                                label="External url",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "new_tab",
                                                            wagtail.blocks.BooleanBlock(
                                                                default=False,
                                                                label="Open in new tab",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "button_style",
                                                            wagtail.blocks.ChoiceBlock(
                                                                choices=[
                                                                    (
                                                                        "primary",
                                                                        "Primary",
                                                                    ),
                                                                    (
                                                                        "secondary",
                                                                        "Secondary",
                                                                    ),
                                                                    ("light", "Light"),
                                                                    ("dark", "Dark"),
                                                                    ("info", "Info"),
                                                                    (
                                                                        "success",
                                                                        "Success",
                                                                    ),
                                                                    (
                                                                        "warning",
                                                                        "Warning",
                                                                    ),
                                                                    (
                                                                        "danger",
                                                                        "Danger",
                                                                    ),
                                                                ],
                                                                label="Button style",
                                                                required=False,
                                                            ),
                                                        ),
                                                    ]
                                                ),
                                                label="Buttons",
                                                required=False,
                                            ),
                                        ),
                                        (
                                            "image",
                                            wagtail.images.blocks.ImageChooserBlock(
                                                label="Afbeelding"
                                            ),
                                        ),
                                        (
                                            "overlay",
                                            wagtail.blocks.BooleanBlock(
                                                label="Dark overlay", required=False
                                            ),
                                        ),
                                        (
                                            "center_text",
                                            wagtail.blocks.BooleanBlock(
                                                label="Center the body", required=False
                                            ),
                                        ),
                                    ],
                                    icon="chain-broken",
                                ),
                            ),
                            (
                                "Nieuwsbrief",
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            "body",
                                            wagtail.blocks.RichTextBlock(
                                                label="Inhoud", required=True
                                            ),
                                        ),
                                        (
                                            "buttons",
                                            wagtail.blocks.ListBlock(
                                                wagtail.blocks.StructBlock(
                                                    [
                                                        (
                                                            "label",
                                                            wagtail.blocks.CharBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "page_url",
                                                            wagtail.blocks.PageChooserBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "external_url",
                                                            wagtail.blocks.CharBlock(
                                                                help_text="You can also use the mailto: or tel: preset for functional use",
                                                                label="External url",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "new_tab",
                                                            wagtail.blocks.BooleanBlock(
                                                                default=False,
                                                                label="Open in new tab",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "button_style",
                                                            wagtail.blocks.ChoiceBlock(
                                                                choices=[
                                                                    (
                                                                        "primary",
                                                                        "Primary",
                                                                    ),
                                                                    (
                                                                        "secondary",
                                                                        "Secondary",
                                                                    ),
                                                                    ("light", "Light"),
                                                                    ("dark", "Dark"),
                                                                    ("info", "Info"),
                                                                    (
                                                                        "success",
                                                                        "Success",
                                                                    ),
                                                                    (
                                                                        "warning",
                                                                        "Warning",
                                                                    ),
                                                                    (
                                                                        "danger",
                                                                        "Danger",
                                                                    ),
                                                                ],
                                                                label="Button style",
                                                                required=False,
                                                            ),
                                                        ),
                                                    ]
                                                ),
                                                label="Buttons",
                                                required=False,
                                            ),
                                        ),
                                        (
                                            "image",
                                            wagtail.images.blocks.ImageChooserBlock(
                                                label="Afbeelding"
                                            ),
                                        ),
                                        (
                                            "overlay",
                                            wagtail.blocks.BooleanBlock(
                                                label="Dark overlay", required=False
                                            ),
                                        ),
                                        (
                                            "center_text",
                                            wagtail.blocks.BooleanBlock(
                                                label="Center the body", required=False
                                            ),
                                        ),
                                    ],
                                    icon="mail",
                                ),
                            ),
                        ],
                        blank=True,
                        verbose_name="Footer",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
            bases=("wagtailcore.page",),
        ),
        migrations.AlterField(
            model_name="coyotehomepage",
            name="content",
            field=wagtail.fields.StreamField(
                [
                    (
                        "Afbeelding_met_tekst",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ],
                            icon="image",
                        ),
                    ),
                    (
                        "Iconen_met_tekst",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "layout",
                                    wagtail.blocks.ChoiceBlock(
                                        choices=[
                                            (
                                                "layout1",
                                                "coyote/layouts/icon_layout_1.svg",
                                            ),
                                            (
                                                "layout2",
                                                "coyote/layouts/icon_layout_2.svg",
                                            ),
                                        ]
                                    ),
                                ),
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "icons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "icon",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "header",
                                                    wagtail.blocks.CharBlock(
                                                        label="Header", required=False
                                                    ),
                                                ),
                                                (
                                                    "body",
                                                    wagtail.blocks.TextBlock(
                                                        label="Short text",
                                                        max_length=100,
                                                        required=True,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Text Block",
                                        required=False,
                                    ),
                                ),
                                (
                                    "button",
                                    wagtail.blocks.StructBlock(
                                        [
                                            (
                                                "label",
                                                wagtail.blocks.CharBlock(
                                                    required=False
                                                ),
                                            ),
                                            (
                                                "page_url",
                                                wagtail.blocks.PageChooserBlock(
                                                    required=False
                                                ),
                                            ),
                                            (
                                                "external_url",
                                                wagtail.blocks.CharBlock(
                                                    help_text="You can also use the mailto: or tel: preset for functional use",
                                                    label="External url",
                                                    required=False,
                                                ),
                                            ),
                                            (
                                                "new_tab",
                                                wagtail.blocks.BooleanBlock(
                                                    default=False,
                                                    label="Open in new tab",
                                                    required=False,
                                                ),
                                            ),
                                            (
                                                "button_style",
                                                wagtail.blocks.ChoiceBlock(
                                                    choices=[
                                                        ("primary", "Primary"),
                                                        ("secondary", "Secondary"),
                                                        ("light", "Light"),
                                                        ("dark", "Dark"),
                                                        ("info", "Info"),
                                                        ("success", "Success"),
                                                        ("warning", "Warning"),
                                                        ("danger", "Danger"),
                                                    ],
                                                    label="Button style",
                                                    required=False,
                                                ),
                                            ),
                                        ],
                                        required=False,
                                    ),
                                ),
                            ],
                            icon="info-circle",
                        ),
                    ),
                    (
                        "Center_tekts",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ],
                            icon="collapse-down",
                        ),
                    ),
                    (
                        "Logos",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "logos",
                                    wagtail.blocks.ListBlock(
                                        wagtail.images.blocks.ImageChooserBlock(),
                                        required=False,
                                    ),
                                )
                            ],
                            icon="tag",
                        ),
                    ),
                    (
                        "Quotes",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ],
                            icon="openquote",
                        ),
                    ),
                    (
                        "Jumbotron",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ],
                            icon="form",
                        ),
                    ),
                    (
                        "Accordeon",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ],
                            icon="list-ul",
                        ),
                    ),
                    (
                        "Producten",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ],
                            icon="tag",
                        ),
                    ),
                    (
                        "Categorieen",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ],
                            icon="clipboard-list",
                        ),
                    ),
                ],
                blank=True,
                verbose_name="Inhoud",
            ),
        ),
        migrations.AlterField(
            model_name="coyotehomepage",
            name="footer",
            field=wagtail.fields.StreamField(
                [
                    (
                        "Call_To_Action",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ],
                            icon="chain-broken",
                        ),
                    ),
                    (
                        "Nieuwsbrief",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ],
                            icon="mail",
                        ),
                    ),
                ],
                blank=True,
                verbose_name="Footer",
            ),
        ),
        migrations.AlterField(
            model_name="coyotehomepage",
            name="header",
            field=wagtail.fields.StreamField(
                [
                    (
                        "Foto",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ]
                        ),
                    ),
                    (
                        "Video",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "video",
                                    wagtail.blocks.CharBlock(
                                        label="Video", required=False
                                    ),
                                ),
                                (
                                    "position",
                                    wagtail.blocks.ChoiceBlock(
                                        choices=[
                                            ("full-screen", "Achtergrond"),
                                            ("media-side", "Next to content"),
                                        ],
                                        label="Postion of the media",
                                        required=False,
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                            ]
                        ),
                    ),
                    (
                        "Content",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "position",
                                    wagtail.blocks.ChoiceBlock(
                                        choices=[
                                            ("left", "Links"),
                                            ("right", "Rechts"),
                                        ],
                                        label="Postion of the image",
                                        required=False,
                                    ),
                                ),
                            ]
                        ),
                    ),
                ],
                blank=True,
                verbose_name="Header",
            ),
        ),
    ]
