.textlist{
	.list-wrapper{
		@extend .css-slider;
		@media screen and (max-width: 991px){
			& > div{
				& > div{
					color: var(--icon-block-color);
					background: var(--icon-block-background);
					padding: 2rem;
					border-radius: $border-radius;
				}
			}
		}
	}
}