# Generated by Django 3.2.23 on 2023-11-17 08:45

from django.db import migrations, models
import wagtail.blocks
import wagtail.fields
import wagtail.embeds.blocks
import wagtail.images.blocks


class Migration(migrations.Migration):

    dependencies = [
        ('coyote', '0008_rename_body_bg_colorsetting_body_background'),
    ]

    operations = [
        migrations.AlterField(
            model_name='colorsetting',
            name='gray_200',
            field=models.CharField(default='#e9ecef', max_length=7, verbose_name='Light'),
        ),
        migrations.AlterField(
            model_name='colorsetting',
            name='gray_900',
            field=models.CharField(default='#0B2936', max_length=7, verbose_name='Dark'),
        ),
        migrations.AlterField(
            model_name='colorsetting',
            name='primary',
            field=models.CharField(default='#7772F6', max_length=7),
        ),
        migrations.AlterField(
            model_name='colorsetting',
            name='secondary',
            field=models.CharField(default='#6c757d', max_length=7),
        ),
        migrations.AlterField(
            model_name='coyotehomepage',
            name='header',
            field=wagtail.fields.StreamField([('Foto', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))])), ('Video', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('layout', wagtail.blocks.ChoiceBlock(choices=[('layout1', 'coyote/layouts/video_layout_1.png'), ('layout2', 'coyote/layouts/video_layout_2.png')])), ('video', wagtail.embeds.blocks.EmbedBlock(label='Video', required=False)), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False))])), ('Content', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('position', wagtail.blocks.ChoiceBlock(choices=[('left', 'Links'), ('right', 'Rechts')], label='Postion of the image', required=False))]))], blank=True, verbose_name='Header'),
        ),
    ]
