# Generated by Django 5.2.3 on 2025-09-29 14:03

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("coyote", "0021_fix_incorrect_header_default_setting"),
        ("ocyan_plugin_wagtail", "0029_alter_abstractbasepage_canonical_url"),
    ]

    operations = [
        migrations.AddField(
           model_name="coyotehomepage",
           name="abstractbasepage_ptr",
           field=models.IntegerField(null=True, blank=True),
           preserve_default=False,
       ),
       migrations.AddField(
           model_name="coyotecontactpage",
           name="abstractbasepage_ptr",
           field=models.IntegerField(null=True, blank=True),
           preserve_default=False,
       )
    ]
