ICONS = [
    ("share-nodes-solid", "share-nodes-solid"),
    ("share-nodes", "share-nodes"),
    ("share", "share"),
    ("share-from-square", "share-from-square"),
    ("spider-web", "spider-web"),
    ("folder", "folder"),
    ("folder-solid", "folder-solid"),
    ("list-check", "list-check"),
    ("cloud-arrow-down", "cloud-arrow-down"),
    ("cloud-arrow-down-solid", "cloud-arrow-down-solid"),
    ("download-solid", "download-solid"),
    ("upload", "upload"),
    ("upload-solid", "upload-solid"),
    ("cloud-arrow-up-solid", "cloud-arrow-up-solid"),
    ("cloud-arrow-up", "cloud-arrow-up"),
    ("home", "home"),
    ("phone", "phone"),
    ("comment", "comment"),
    ("cart-arrow-down", "cart-arrow-down"),
    ("cart-shopping-fast", "cart-shopping-fast"),
    ("shopping-cart", "shopping-cart"),
    ("shopping-cart-solid", "shopping-cart-solid"),
    ("trash", "trash"),
    ("arrow-down-arrow-up", "arrow-down-arrow-up"),
    ("sort-numeric-down-alt", "sort-numeric-down-alt"),
    ("sort-alpha-down", "sort-alpha-down"),
    ("circle", "circle"),
    ("filter", "filter"),
    ("cloud", "cloud"),
    ("letter", "letter"),
    ("letter-open", "letter-open"),
    ("envelope-open", "envelope-open"),
    ("envelope", "envelope"),
    ("earth-africa", "earth-africa"),
    ("earth-europe", "earth-europe"),
    ("globe", "globe"),
    ("chevron-down", "chevron-down"),
    ("chevron-left", "chevron-left"),
    ("chevron-right", "chevron-right"),
    ("chevron-up", "chevron-up"),
    ("plus-circle", "plus-circle"),
    ("wallet", "wallet"),
    ("lock-alt-solid", "lock-alt-solid"),
    ("lock-alt", "lock-alt"),
    ("heart", "heart"),
    ("bars", "bars"),
    ("plus", "plus"),
    ("minus", "minus"),
    ("times", "times"),
    ("truck-solid", "truck-solid"),
    ("truck", "truck"),
    ("check", "check"),
    ("receipt-solid", "receipt-solid"),
    ("receipt", "receipt"),
    ("exclamation", "exclamation"),
    ("play", "play"),
    ("star", "star"),
    ("star-half", "star-half"),
    ("arrow-right", "arrow-right"),
    ("arrow-up", "arrow-up"),
    ("arrow-down", "arrow-down"),
    ("arrow-left", "arrow-left"),
    ("heart-solid", "heart-solid"),
    ("info", "info"),
    ("exclamation-triangle", "exclamation-triangle"),
    ("tag", "tag"),
    ("angle-double-down", "angle-double-down"),
    ("angle-double-right", "angle-double-right"),
    ("angle-double-left", "angle-double-left"),
    ("angle-double-up", "angle-double-up"),
    ("angle-right", "angle-right"),
    ("angle-left", "angle-left"),
    ("angle-up", "angle-up"),
    ("angle-down", "angle-down"),
    ("chevron-double-right", "chevron-double-right"),
    ("chevron-double-left", "chevron-double-left"),
    ("chevron-double-down", "chevron-double-down"),
    ("chevron-double-up", "chevron-double-up"),
    ("users", "users"),
    ("badge-check", "badge-check"),
    ("arrow-circle-right", "arrow-circle-right"),
    ("arrow-circle-down", "arrow-circle-down"),
    ("check-circle", "check-circle"),
    ("arrow-circle-left", "arrow-circle-left"),
    ("arrow-circle-up", "arrow-circle-up"),
    ("th", "th"),
    ("ruler", "ruler"),
    ("question", "question"),
    ("headphones", "headphones"),
    ("shopping-bag", "shopping-bag"),
    ("minus-circle", "minus-circle"),
    ("leaf", "leaf"),
    ("star-half-solid", "star-half-solid"),
    ("star-solid", "star-solid"),
    ("user-solid", "user-solid"),
    ("lock-solid", "lock-solid"),
    ("bell-solid", "bell-solid"),
    ("thumbs-up-solid", "thumbs-up-solid"),
    ("thumbs-down-solid", "thumbs-down-solid"),
    ("cog-solid", "cog-solid"),
    ("paper-plane", "paper-plane"),
    ("address-book", "address-book"),
    ("inbox", "inbox"),
    ("tags", "tags"),
    ("map-marker-alt", "map-marker-alt"),
    ("box-open", "box-open"),
    ("cog", "cog"),
    ("fire", "fire"),
    ("sync", "sync"),
    ("sync-alt", "sync-alt"),
    ("long-arrow-right", "long-arrow-right"),
    ("search", "search"),
    ("location", "location"),
    ("megaphone", "megaphone"),
    ("thumbs-up", "thumbs-up"),
    ("thumbs-down", "thumbs-down"),
    ("list", "list"),
    ("pencil", "pencil"),
    ("eye-slash", "eye-slash"),
    ("eye", "eye"),
    ("check-fas", "check-fas"),
    ("sign-out", "sign-out"),
    ("user", "user"),
    ("bell", "bell"),
    ("download", "download"),
    ("clock", "clock"),
    ("trash-alt", "trash-alt"),
    ("clipboard-list", "clipboard-list"),
    ("layer-group", "layer-group"),
    ("layer-plus", "layer-plus"),
    ("info-circle", "info-circle"),
    ("info-square", "info-square"),
    ("times-circle", "times-circle"),
    ("tags-solid", "tags-solid"),
    ("address-book-solid", "address-book-solid"),
    ("paper-plane-solid", "paper-plane-solid"),
    ("inbox-solid", "inbox-solid"),
    ("archive-solid", "archive-solid"),
    ("long-arrow-left", "long-arrow-left"),
    ("exchange", "exchange"),
    ("directions-solid", "directions-solid"),
    ("directions", "directions"),
    ("calendar-range", "calendar-range"),
    ("calendar-alt", "calendar-alt"),
    ("sliders", "sliders"),
    ("user-secret", "user-secret"),
    ("pause", "pause"),
    ("rocket-launch", "rocket-launch"),
    ("mug-hot", "mug-hot"),
    ("calendar-days", "calendar-days"),
    ("share-from", "share-from"),
    ("bag-shopping", "bag-shopping"),
    ("copy-regular", "copy-regular"),
    ("glass", "glass"),
    ("folder-open", "folder-open"),
    ("frown-o", "frown-o"),
    ("clipboard", "clipboard"),
    ("xmark", "xmark"),
    ("magnifying-glass-minus", "magnifying-glass-minus"),
    ("magnifying-glass-plus", "magnifying-glass-plus"),
    ("caret-up", "caret-up"),
    ("caret-right", "caret-right"),
    ("caret-left", "caret-left"),
    ("caret-down", "caret-down"),
    ("pinterest", "pinterest"),
    ("facebook", "facebook"),
    ("whatsapp", "whatsapp"),
    ("instagram", "instagram"),
    ("youtube", "youtube"),
    ("google-plus", "google-plus"),
    ("linkedin", "linkedin"),
    ("twitter", "twitter"),
]
