oxyan.initSliders(".quotes_wrapper", {
  loop: false,
  nav: true,
  autoplay: false,
  autoHeight: false,
  items: 1,
  gutter: 60,
});

oxyan.initSliders(".coyote-product-block-slider", {
  lazy: true,
  controls: true,
  nav: true,
  autoplayHoverPause: true,
  loop: true,
  autoplay: true,
  autoplayTimeout: 3000,
  slideBy: 1,
  gutter: 30,
  autoHeight: false,
  responsive: {
    0: {
      items: 2,
      edgePadding: 0,
    },
    991: {
      items: 4,
      edgePadding: 0,
    },
  },
});

oxyan.initSliders(".coyote-product-block-slider2", {
  lazy: true,
  controls: true,
  nav: true,
  autoplayHoverPause: true,
  loop: true,
  autoplay: true,
  autoplayTimeout: 3000,
  slideBy: 1,
  items: 5,
  gutter: 30,
  autoHeight: false,
  responsive: {
    0: {
      items: 2,
      edgePadding: 0,
    },
    991: {
      items: 4,
      edgePadding: 0,
    },
  },
});

oxyan.initSliders(".coyote-category-block-slider", {
  lazy: true,
  controls: true,
  nav: true,
  autoplayHoverPause: true,
  loop: true,
  autoplay: true,
  autoplayTimeout: 3000,
  slideBy: 1,
  items: 2,
  gutter: 30,
  autoHeight: false,
  responsive: {
    0: {
      items: 1,
      edgePadding: 0,
    },
    991: {
      items: 2,
      edgePadding: 0,
    },
  },
});
