# Generated by Django 3.2.20 on 2023-10-26 07:05

from django.db import migrations, models
import django.db.models.deletion
import wagtail.blocks
import wagtail.fields
import wagtail.embeds.blocks
import wagtail.images.blocks


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailimages', '0023_add_choose_permissions'),
        ('coyote', '0003_auto_20230907_1200'),
    ]

    operations = [
        migrations.AddField(
            model_name='coyotecontactpage',
            name='search_image',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.image', verbose_name='Search image'),
        ),
        migrations.AddField(
            model_name='coyotehomepage',
            name='search_image',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.image', verbose_name='Search image'),
        ),
        migrations.AlterField(
            model_name='coyotecontactpage',
            name='content',
            field=wagtail.fields.StreamField([('Info_blokjes', wagtail.blocks.StructBlock([('main_title', wagtail.blocks.CharBlock(lable='Hoofd titel', required=False)), ('main_text', wagtail.blocks.RichTextBlock(label='Hoofd tekst', required=False)), ('blok', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('title', wagtail.blocks.CharBlock(label='Blokje titel', required=True)), ('text', wagtail.blocks.RichTextBlock(label='Blokje tekst', required=True)), ('link', wagtail.blocks.CharBlock(label='Lees meer', required=True))]), collapsed=True, required=True))], icon='list-ol')), ('accordion', wagtail.blocks.StructBlock([('image', wagtail.images.blocks.ImageChooserBlock(label='foto', required=True)), ('title', wagtail.blocks.CharBlock(label='Titel van de tekst', required=False)), ('text', wagtail.blocks.RichTextBlock(label='Tekst', required=False)), ('accordion', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('title_accordion', wagtail.blocks.CharBlock(label='Accordion titel ', required=False)), ('text_accordion', wagtail.blocks.RichTextBlock(label='Accordion text ', required=False))]), collapsed=True, required=True))], icon='info-circle')), ('Center_tekts', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))], icon='collapse-down')), ('Logos', wagtail.blocks.StructBlock([('header', wagtail.blocks.CharBlock(label='Header', required=False)), ('logos', wagtail.blocks.ListBlock(wagtail.images.blocks.ImageChooserBlock(), collapsed=True, required=False))], icon='tag')), ('Quotes', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))], icon='openquote')), ('Jumbotron', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))], icon='form')), ('Accordeon', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))], icon='list-ul')), ('Producten', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))], icon='tag')), ('Categorieen', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))], icon='clipboard-list'))], blank=True, verbose_name='Inhoud'),
        ),
        migrations.AlterField(
            model_name='coyotecontactpage',
            name='footer',
            field=wagtail.fields.StreamField([('Call_To_Action', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))], icon='chain-broken')), ('Nieuwsbrief', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))], icon='mail'))], blank=True, verbose_name='Footer'),
        ),
        migrations.AlterField(
            model_name='coyotecontactpage',
            name='header',
            field=wagtail.fields.StreamField([('Foto', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('title', wagtail.blocks.CharBlock(label='titel', required=True)), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))]))], blank=True, verbose_name='Header'),
        ),
        migrations.AlterField(
            model_name='coyotehomepage',
            name='content',
            field=wagtail.fields.StreamField([('Afbeelding_met_tekst', wagtail.blocks.StructBlock([('layout', wagtail.blocks.ChoiceBlock(choices=[('layout1', 'coyote/layouts/layout_image_text_2.png'), ('layout2', 'coyote/layouts/layout_image_text_1.png')])), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('title', wagtail.blocks.CharBlock(label='titel', required=True)), ('body', wagtail.blocks.TextBlock(required=False)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('counter', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('number', wagtail.blocks.CharBlock(required=False)), ('label', wagtail.blocks.CharBlock(required=False))]), collapsed=True, label='Counter', required=False))], icon='image')), ('Iconen_met_tekst', wagtail.blocks.StructBlock([('layout', wagtail.blocks.ChoiceBlock(choices=[('layout1', 'coyote/layouts/icon_layout_1.png'), ('layout2', 'coyote/layouts/icon_layout_2.png')])), ('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('icons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('icon', wagtail.blocks.ChoiceBlock(choices=[('share-nodes-solid', 'share-nodes-solid'), ('share-nodes', 'share-nodes'), ('share', 'share'), ('share-from-square', 'share-from-square'), ('spider-web', 'spider-web'), ('folder', 'folder'), ('folder-solid', 'folder-solid'), ('list-check', 'list-check'), ('cloud-arrow-down', 'cloud-arrow-down'), ('cloud-arrow-down-solid', 'cloud-arrow-down-solid'), ('download-solid', 'download-solid'), ('upload', 'upload'), ('upload-solid', 'upload-solid'), ('cloud-arrow-up-solid', 'cloud-arrow-up-solid'), ('cloud-arrow-up', 'cloud-arrow-up'), ('home', 'home'), ('phone', 'phone'), ('comment', 'comment'), ('cart-arrow-down', 'cart-arrow-down'), ('cart-shopping-fast', 'cart-shopping-fast'), ('shopping-cart', 'shopping-cart'), ('shopping-cart-solid', 'shopping-cart-solid'), ('trash', 'trash'), ('arrow-down-arrow-up', 'arrow-down-arrow-up'), ('sort-numeric-down-alt', 'sort-numeric-down-alt'), ('sort-alpha-down', 'sort-alpha-down'), ('circle', 'circle'), ('filter', 'filter'), ('cloud', 'cloud'), ('letter', 'letter'), ('letter-open', 'letter-open'), ('envelope-open', 'envelope-open'), ('envelope', 'envelope'), ('earth-africa', 'earth-africa'), ('earth-europe', 'earth-europe'), ('globe', 'globe'), ('chevron-down', 'chevron-down'), ('chevron-left', 'chevron-left'), ('chevron-right', 'chevron-right'), ('chevron-up', 'chevron-up'), ('plus-circle', 'plus-circle'), ('wallet', 'wallet'), ('lock-alt-solid', 'lock-alt-solid'), ('lock-alt', 'lock-alt'), ('heart', 'heart'), ('bars', 'bars'), ('plus', 'plus'), ('minus', 'minus'), ('times', 'times'), ('truck-solid', 'truck-solid'), ('truck', 'truck'), ('check', 'check'), ('receipt-solid', 'receipt-solid'), ('receipt', 'receipt'), ('exclamation', 'exclamation'), ('play', 'play'), ('star', 'star'), ('star-half', 'star-half'), ('arrow-right', 'arrow-right'), ('arrow-up', 'arrow-up'), ('arrow-down', 'arrow-down'), ('arrow-left', 'arrow-left'), ('heart-solid', 'heart-solid'), ('info', 'info'), ('exclamation-triangle', 'exclamation-triangle'), ('tag', 'tag'), ('angle-double-down', 'angle-double-down'), ('angle-double-right', 'angle-double-right'), ('angle-double-left', 'angle-double-left'), ('angle-double-up', 'angle-double-up'), ('angle-right', 'angle-right'), ('angle-left', 'angle-left'), ('angle-up', 'angle-up'), ('angle-down', 'angle-down'), ('chevron-double-right', 'chevron-double-right'), ('chevron-double-left', 'chevron-double-left'), ('chevron-double-down', 'chevron-double-down'), ('chevron-double-up', 'chevron-double-up'), ('users', 'users'), ('badge-check', 'badge-check'), ('arrow-circle-right', 'arrow-circle-right'), ('arrow-circle-down', 'arrow-circle-down'), ('check-circle', 'check-circle'), ('arrow-circle-left', 'arrow-circle-left'), ('arrow-circle-up', 'arrow-circle-up'), ('th', 'th'), ('ruler', 'ruler'), ('question', 'question'), ('headphones', 'headphones'), ('shopping-bag', 'shopping-bag'), ('minus-circle', 'minus-circle'), ('leaf', 'leaf'), ('star-half-solid', 'star-half-solid'), ('star-solid', 'star-solid'), ('user-solid', 'user-solid'), ('lock-solid', 'lock-solid'), ('bell-solid', 'bell-solid'), ('thumbs-up-solid', 'thumbs-up-solid'), ('thumbs-down-solid', 'thumbs-down-solid'), ('cog-solid', 'cog-solid'), ('paper-plane', 'paper-plane'), ('address-book', 'address-book'), ('inbox', 'inbox'), ('tags', 'tags'), ('map-marker-alt', 'map-marker-alt'), ('box-open', 'box-open'), ('cog', 'cog'), ('fire', 'fire'), ('sync', 'sync'), ('sync-alt', 'sync-alt'), ('long-arrow-right', 'long-arrow-right'), ('search', 'search'), ('location', 'location'), ('megaphone', 'megaphone'), ('thumbs-up', 'thumbs-up'), ('thumbs-down', 'thumbs-down'), ('list', 'list'), ('pencil', 'pencil'), ('eye-slash', 'eye-slash'), ('eye', 'eye'), ('check-fas', 'check-fas'), ('sign-out', 'sign-out'), ('user', 'user'), ('bell', 'bell'), ('download', 'download'), ('clock', 'clock'), ('trash-alt', 'trash-alt'), ('clipboard-list', 'clipboard-list'), ('layer-group', 'layer-group'), ('layer-plus', 'layer-plus'), ('info-circle', 'info-circle'), ('info-square', 'info-square'), ('times-circle', 'times-circle'), ('tags-solid', 'tags-solid'), ('address-book-solid', 'address-book-solid'), ('paper-plane-solid', 'paper-plane-solid'), ('inbox-solid', 'inbox-solid'), ('archive-solid', 'archive-solid'), ('long-arrow-left', 'long-arrow-left'), ('exchange', 'exchange'), ('directions-solid', 'directions-solid'), ('directions', 'directions'), ('calendar-range', 'calendar-range'), ('calendar-alt', 'calendar-alt'), ('sliders', 'sliders'), ('user-secret', 'user-secret'), ('pause', 'pause'), ('rocket-launch', 'rocket-launch'), ('mug-hot', 'mug-hot'), ('calendar-days', 'calendar-days'), ('share-from', 'share-from'), ('bag-shopping', 'bag-shopping'), ('copy-regular', 'copy-regular'), ('glass', 'glass'), ('folder-open', 'folder-open'), ('frown-o', 'frown-o'), ('clipboard', 'clipboard'), ('xmark', 'xmark'), ('magnifying-glass-minus', 'magnifying-glass-minus'), ('magnifying-glass-plus', 'magnifying-glass-plus'), ('caret-up', 'caret-up'), ('caret-right', 'caret-right'), ('caret-left', 'caret-left'), ('caret-down', 'caret-down'), ('pinterest', 'pinterest'), ('facebook', 'facebook'), ('whatsapp', 'whatsapp'), ('instagram', 'instagram'), ('youtube', 'youtube'), ('google-plus', 'google-plus'), ('linkedin', 'linkedin'), ('twitter', 'twitter')], required=False)), ('header', wagtail.blocks.CharBlock(label='Header', required=False)), ('body', wagtail.blocks.TextBlock(label='Short text', max_length=100, required=False)), ('page', wagtail.blocks.PageChooserBlock(label='Pagina url', required=False))]), collapsed=True, label='Text Block', required=False)), ('button', wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))], required=False))], icon='info-circle')), ('Center_tekts', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(required=False))], icon='collapse-down')), ('Logos', wagtail.blocks.StructBlock([('header', wagtail.blocks.CharBlock(label='Header', required=False)), ('logos', wagtail.blocks.ListBlock(wagtail.images.blocks.ImageChooserBlock(), collapsed=True, required=False))], icon='tag')), ('Quotes', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))], icon='openquote')), ('Jumbotron', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))], icon='form')), ('Accordeon', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))], icon='list-ul')), ('Tabs', wagtail.blocks.StructBlock([('header', wagtail.blocks.CharBlock(label='Header', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('tabs', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('header', wagtail.blocks.CharBlock(label='Header')), ('body', wagtail.blocks.RichTextBlock(label='Inhoud')), ('button', wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))], required=False))]), collapsed=True, label='Tabs', required=False))], icon='list-ul')), ('Producten', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))], icon='tag')), ('Categorieen', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))], icon='clipboard-list'))], blank=True, verbose_name='Inhoud'),
        ),
        migrations.AlterField(
            model_name='coyotehomepage',
            name='footer',
            field=wagtail.fields.StreamField([('Call_To_Action', wagtail.blocks.StructBlock([('icon', wagtail.blocks.ChoiceBlock(choices=[('share-nodes-solid', 'share-nodes-solid'), ('share-nodes', 'share-nodes'), ('share', 'share'), ('share-from-square', 'share-from-square'), ('spider-web', 'spider-web'), ('folder', 'folder'), ('folder-solid', 'folder-solid'), ('list-check', 'list-check'), ('cloud-arrow-down', 'cloud-arrow-down'), ('cloud-arrow-down-solid', 'cloud-arrow-down-solid'), ('download-solid', 'download-solid'), ('upload', 'upload'), ('upload-solid', 'upload-solid'), ('cloud-arrow-up-solid', 'cloud-arrow-up-solid'), ('cloud-arrow-up', 'cloud-arrow-up'), ('home', 'home'), ('phone', 'phone'), ('comment', 'comment'), ('cart-arrow-down', 'cart-arrow-down'), ('cart-shopping-fast', 'cart-shopping-fast'), ('shopping-cart', 'shopping-cart'), ('shopping-cart-solid', 'shopping-cart-solid'), ('trash', 'trash'), ('arrow-down-arrow-up', 'arrow-down-arrow-up'), ('sort-numeric-down-alt', 'sort-numeric-down-alt'), ('sort-alpha-down', 'sort-alpha-down'), ('circle', 'circle'), ('filter', 'filter'), ('cloud', 'cloud'), ('letter', 'letter'), ('letter-open', 'letter-open'), ('envelope-open', 'envelope-open'), ('envelope', 'envelope'), ('earth-africa', 'earth-africa'), ('earth-europe', 'earth-europe'), ('globe', 'globe'), ('chevron-down', 'chevron-down'), ('chevron-left', 'chevron-left'), ('chevron-right', 'chevron-right'), ('chevron-up', 'chevron-up'), ('plus-circle', 'plus-circle'), ('wallet', 'wallet'), ('lock-alt-solid', 'lock-alt-solid'), ('lock-alt', 'lock-alt'), ('heart', 'heart'), ('bars', 'bars'), ('plus', 'plus'), ('minus', 'minus'), ('times', 'times'), ('truck-solid', 'truck-solid'), ('truck', 'truck'), ('check', 'check'), ('receipt-solid', 'receipt-solid'), ('receipt', 'receipt'), ('exclamation', 'exclamation'), ('play', 'play'), ('star', 'star'), ('star-half', 'star-half'), ('arrow-right', 'arrow-right'), ('arrow-up', 'arrow-up'), ('arrow-down', 'arrow-down'), ('arrow-left', 'arrow-left'), ('heart-solid', 'heart-solid'), ('info', 'info'), ('exclamation-triangle', 'exclamation-triangle'), ('tag', 'tag'), ('angle-double-down', 'angle-double-down'), ('angle-double-right', 'angle-double-right'), ('angle-double-left', 'angle-double-left'), ('angle-double-up', 'angle-double-up'), ('angle-right', 'angle-right'), ('angle-left', 'angle-left'), ('angle-up', 'angle-up'), ('angle-down', 'angle-down'), ('chevron-double-right', 'chevron-double-right'), ('chevron-double-left', 'chevron-double-left'), ('chevron-double-down', 'chevron-double-down'), ('chevron-double-up', 'chevron-double-up'), ('users', 'users'), ('badge-check', 'badge-check'), ('arrow-circle-right', 'arrow-circle-right'), ('arrow-circle-down', 'arrow-circle-down'), ('check-circle', 'check-circle'), ('arrow-circle-left', 'arrow-circle-left'), ('arrow-circle-up', 'arrow-circle-up'), ('th', 'th'), ('ruler', 'ruler'), ('question', 'question'), ('headphones', 'headphones'), ('shopping-bag', 'shopping-bag'), ('minus-circle', 'minus-circle'), ('leaf', 'leaf'), ('star-half-solid', 'star-half-solid'), ('star-solid', 'star-solid'), ('user-solid', 'user-solid'), ('lock-solid', 'lock-solid'), ('bell-solid', 'bell-solid'), ('thumbs-up-solid', 'thumbs-up-solid'), ('thumbs-down-solid', 'thumbs-down-solid'), ('cog-solid', 'cog-solid'), ('paper-plane', 'paper-plane'), ('address-book', 'address-book'), ('inbox', 'inbox'), ('tags', 'tags'), ('map-marker-alt', 'map-marker-alt'), ('box-open', 'box-open'), ('cog', 'cog'), ('fire', 'fire'), ('sync', 'sync'), ('sync-alt', 'sync-alt'), ('long-arrow-right', 'long-arrow-right'), ('search', 'search'), ('location', 'location'), ('megaphone', 'megaphone'), ('thumbs-up', 'thumbs-up'), ('thumbs-down', 'thumbs-down'), ('list', 'list'), ('pencil', 'pencil'), ('eye-slash', 'eye-slash'), ('eye', 'eye'), ('check-fas', 'check-fas'), ('sign-out', 'sign-out'), ('user', 'user'), ('bell', 'bell'), ('download', 'download'), ('clock', 'clock'), ('trash-alt', 'trash-alt'), ('clipboard-list', 'clipboard-list'), ('layer-group', 'layer-group'), ('layer-plus', 'layer-plus'), ('info-circle', 'info-circle'), ('info-square', 'info-square'), ('times-circle', 'times-circle'), ('tags-solid', 'tags-solid'), ('address-book-solid', 'address-book-solid'), ('paper-plane-solid', 'paper-plane-solid'), ('inbox-solid', 'inbox-solid'), ('archive-solid', 'archive-solid'), ('long-arrow-left', 'long-arrow-left'), ('exchange', 'exchange'), ('directions-solid', 'directions-solid'), ('directions', 'directions'), ('calendar-range', 'calendar-range'), ('calendar-alt', 'calendar-alt'), ('sliders', 'sliders'), ('user-secret', 'user-secret'), ('pause', 'pause'), ('rocket-launch', 'rocket-launch'), ('mug-hot', 'mug-hot'), ('calendar-days', 'calendar-days'), ('share-from', 'share-from'), ('bag-shopping', 'bag-shopping'), ('copy-regular', 'copy-regular'), ('glass', 'glass'), ('folder-open', 'folder-open'), ('frown-o', 'frown-o'), ('clipboard', 'clipboard'), ('xmark', 'xmark'), ('magnifying-glass-minus', 'magnifying-glass-minus'), ('magnifying-glass-plus', 'magnifying-glass-plus'), ('caret-up', 'caret-up'), ('caret-right', 'caret-right'), ('caret-left', 'caret-left'), ('caret-down', 'caret-down'), ('pinterest', 'pinterest'), ('facebook', 'facebook'), ('whatsapp', 'whatsapp'), ('instagram', 'instagram'), ('youtube', 'youtube'), ('google-plus', 'google-plus'), ('linkedin', 'linkedin'), ('twitter', 'twitter')], required=False)), ('header', wagtail.blocks.CharBlock(required=False)), ('body', wagtail.blocks.TextBlock(required=False)), ('button', wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))], required=False))], icon='chain-broken')), ('Nieuwsbrief', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))], icon='mail'))], blank=True, verbose_name='Footer'),
        ),
        migrations.AlterField(
            model_name='coyotehomepage',
            name='header',
            field=wagtail.fields.StreamField([('Foto', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))])), ('Video', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('video', wagtail.embeds.blocks.EmbedBlock(label='Video', required=False)), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False))])), ('Content', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('position', wagtail.blocks.ChoiceBlock(choices=[('left', 'Links'), ('right', 'Rechts')], label='Postion of the image', required=False))]))], blank=True, verbose_name='Header'),
        ),
    ]
