# Generated by Django 3.2.23 on 2023-11-24 11:12

from django.db import migrations, models
import wagtail.blocks
import wagtail.fields
import wagtail.embeds.blocks
import wagtail.images.blocks

from oxyan.themes.definitions import theme


class Migration(migrations.Migration):

    dependencies = [
        ('coyote', '0009_auto_20231117_0945'),
    ]

    operations = [
        migrations.AddField(
            model_name='colorsetting',
            name='footer_background',
            field=models.CharField(default=theme["header-background"], max_length=7, verbose_name='Background footer'),
        ),
        migrations.AddField(
            model_name='colorsetting',
            name='header_background',
            field=models.CharField(default=theme["header-background"], max_length=7, verbose_name='Background header'),
        ),
        migrations.AlterField(
            model_name='colorsetting',
            name='gray_200',
            field=models.CharField(default=theme["gray-200"], max_length=7, verbose_name='Light'),
        ),
        migrations.AlterField(
            model_name='colorsetting',
            name='gray_900',
            field=models.CharField(default=theme["gray-900"], max_length=7, verbose_name='Dark'),
        ),
        migrations.AlterField(
            model_name='colorsetting',
            name='primary',
            field=models.CharField(default=theme["primary"], max_length=7),
        ),
        migrations.AlterField(
            model_name='colorsetting',
            name='secondary',
            field=models.CharField(default=theme["secondary"], max_length=7),
        ),
        migrations.AlterField(
            model_name='coyotecontactpage',
            name='content',
            field=wagtail.fields.StreamField([], blank=True, verbose_name='Inhoud'),
        ),
        migrations.AlterField(
            model_name='coyotehomepage',
            name='content',
            field=wagtail.fields.StreamField([], blank=True, verbose_name='Inhoud'),
        ),
        migrations.AlterField(
            model_name='coyotehomepage',
            name='header',
            field=wagtail.fields.StreamField([], blank=True, verbose_name='Header'),
        ),
    ]
