// Template is located in the wagtail_blog plugin
.blogs-wrapper{
	@extend .coyote-block-wrapper;
	.blog-item{
		a{
			color: inherit;
			text-decoration: unset;
		}
		.blog-info{
			padding: 0;
			padding-top: 1rem;
			border: 0;
			p{
				opacity: .7;
				margin: 1rem 0;
			}
			.read_more{
				transition: .2s ease;
			}
		}
		.blog-image-wrapper{
			position: relative;
			overflow: hidden;
			z-index: 1;
			height: 250px;
			border-radius: $border-radius;
			.blog-image{
				width: 100%;
				height: 100%;
				object-fit: cover;
				position: absolute;
				top: 0;
				left: 0;
				transition: 2s cubic-bezier(.3,1,.3,1);
			}
		}
		&:hover{
			.read_more{
				color: $primary;
			}
			.blog-image{
				transform: scale(1.1);
				transition: 1s cubic-bezier(.3,1,.3,1);
			}
		}
		.blog-date{
			display: none;
		}
	}
}