# Generated by Django 4.2.11 on 2025-05-12 14:42

from django.db import migrations
from oxyan.themes.definitions import theme


def forward(apps, schema_editor):
    StyleSettings = apps.get_model("coyote", "StyleSettings")

    if qs := StyleSettings.objects.filter(border_radius=0.0):
        qs.update(border_radius=theme["border-radius"])


class Migration(migrations.Migration):

    dependencies = [
        ("coyote", "0018_alter_stylesettings_border_radius"),
    ]

    operations = [
        migrations.RunPython(forward, migrations.RunPython.noop)
    ]
