{% load ocyan_thumbnail %}
<section class="iconslider-wrapper {{self.coyote_bg}}" id="{{ self.coyote_anchor }}">
	<div class="container">
		<div class="row">
			{% if self.header %}
			<div class="col-lg-12 mb-5 text-center">
				<h3>{{ self.header }}</h3>
			</div>
			{% endif %}
			<div class="col-lg-12">
				<div class="{% if self.logos|length > 5 %}iconslider{% else %}icon-wrapper{% endif %}">
					{% for slide in self.logos %}
					<div>
						{% picture slide.file "800x800" %}
					</div>
					{% endfor %}
				</div>
			</div>
		</div>
	</div>
</section>
