{% extends "coyote/coyote_page.html" %}
{% load wagtailcore_tags static %}

{% block content %}
	{% include_block self.header %}
	<div class="coyote-wrapper">
		{% include_block self.content %}
	</div>
	{% include_block self.footer %}
{% endblock %}

{% block styles %}
	{{block.super}}
	{% include "coyote/partials/styles/contact_styles.html" %}
{% endblock %}
