{% load ocyan_thumbnail wagtailcore_tags styling_tags %}
<section class="info-block-wrapper {{self.coyote_bg}}" id="{{ self.coyote_anchor }}">
    <div class="container">
        <div class="info-block-wrapper">
            <div class="d-flex justify-content-center">
                <div class="main-info">
                    <h4>{{ self.main_title }}</h4>
                    <p>{{ self.main_text }}</p>
                </div>
            </div>
            <div class="blokje-wrapper d-flex justify-content-center justify-content-between px-5 ms-auto">
            {% for blokje in self.blok %}
                <div class="blokje-info p-5 ms-auto">
                    <h3>{{ blokje.title }}</h3>
                    <p>{{ blokje.text }}</p>
                    {% if blokje.link %}
                    <a href="{{ blokje.link }}">{{ blokje.link }} <i class="fa fa-arrow-right px-1" aria-hidden="true"></i></a>
                    {% endif %}
                </div>
            {% endfor %}
            </div>
        </div>
    </div>
</section>
