{% extends "coyote/coyote_page.html" %}
{% load wagtailcore_tags static %}

{% block content %}
	<div class="coyote">
		{% include_block self.header %}
		<div class="coyote-wrapper{% if self.footer %} footer_colored{% endif %}">
			{% include_block self.content %}
		</div>
		{% include_block self.footer %}
	</div>
{% endblock %}

{% block styles %}
	{{block.super}}
	{% include "coyote/partials/styles/home_styles.html" %}
{% endblock %}

{% block extrascripts %}
    {{ block.super }}
    <script type="text/javascript" src="{% static 'coyote/js/slider.js' %}"></script>
{% endblock extrascripts %}
