div[data-contentpath=coyote_anchor]{height:0px;padding:0 !important;margin:0 !important}.coyote_inline{display:flex;flex-direction:row;flex-wrap:wrap;gap:2rem}.coyote_inline .field{margin-left:0;display:flex;flex-direction:row-reverse;cursor:pointer;padding-top:0 !important}.coyote_inline .field label{padding-left:.25rem;font-weight:500}.coyote_chooser .button_input_wrapper{position:relative;display:flex;align-items:center;justify-content:center}.coyote_chooser .button_input_wrapper button{position:absolute;right:1rem}.coyote_chooser .button_input_wrapper input[type=text]{width:100%;float:unset;margin-right:0;padding-left:3.5rem}.coyote_chooser .svg-wrapper{display:inline-flex;margin-right:.5rem;position:absolute;left:.75rem}.coyote_chooser .svg-wrapper svg{color:#d9d9d9;width:2.5em;height:2.5em;vertical-align:text-top;vertical-align:middle}
.icon-choice{display:flex;flex-wrap:wrap;width:100%;max-width:800px;background:#fff;padding:2rem;border-radius:1rem;transition:.5s ease;transition-delay:.25s}.icon-choice input[type=radio]{display:none}.icon-choice input[type=radio]:checked+i{color:var(--w-color-primary)}.icon-choice #search{margin-bottom:1rem}.icon-choice i{padding:0;transition:.2s ease;cursor:pointer;color:#8b8a8a;font-size:1.5rem;margin:.5rem;width:1.5rem;height:1.5rem;display:flex;flex-direction:column;justify-content:center;align-items:center}.icon-choice i:hover{color:#5b5b5b}.icon-choice-modal{position:fixed !important;top:0;left:0;width:100%;height:100%;margin:0;display:flex;flex-direction:column;justify-content:center;align-items:center;background:rgba(0,0,0,.5);z-index:99999;opacity:0;pointer-events:none;transition:.25s ease}.icon-choice-modal.active{opacity:1;pointer-events:all}.icon-choice-modal:not(.active) .icon-choice{transform:translateY(30px);opacity:0}.icon-choice-wrapper{display:flex !important;align-items:center}.button{cursor:pointer}.icon-preview{color:#8b8a8a;font-size:1.5rem;margin:.5rem;margin-left:1rem}
div[data-contentpath=coyote_bg]{height:0px;padding:0 !important;margin:0 !important}.color-choice{display:flex;position:absolute;top:-0.5rem;right:0}.color-choice input[type=radio]{display:none}.color-choice input[type=radio]:checked+div{border-color:#02afaf}.color-choice label{padding-bottom:0 !important}.color-choice .preview-color{display:flex;align-items:center;justify-content:center;font-size:1rem;font-weight:100;width:1.5rem;height:1.5rem;margin-right:.3rem;padding:0;overflow:hidden;transition:.2s ease;border:2px solid rgba(0,0,0,0);border-radius:2rem;cursor:pointer;object-fit:contain}.color-choice .preview-color.cross:before{content:"×";color:#fff;mix-blend-mode:exclusion;font-weight:900}.color-choice .preview-color:hover{border-color:#e2e2e2}
.visual-choice{display:flex;flex-wrap:wrap}.visual-choice input[type=radio]{display:none}.visual-choice input[type=radio]:checked+img{border-color:var(--w-color-primary)}.visual-choice label{padding-bottom:0 !important}.visual-choice img{width:150px;height:150px;margin-right:1rem;padding:0;overflow:hidden;transition:.2s ease;border:2px solid #cfcfcf;border-radius:1rem;cursor:pointer;object-fit:contain}.visual-choice img:hover{border-color:#e2e2e2}

/*# sourceMappingURL=coyote.css.map*/