@import "scss/variables";
@import "scss/vendor/bootstrap/functions";
@import "scss/vendor/bootstrap/variables";
@import "../variables";

@import "header";
@import "icon_with_text";
@import "logo_slider";
@import "tabsblock";
@import "calltoaction";
@import "blogs";