oxyan.initSliders(".iconslider", {autoHeight:true, controls:false, nav:false, center:true, autoplay:true, loop:true, slideBy:1, autoplayTimeout:2000, autoplayButtonOutput:false, responsive: {0: {items: 2,}, 991: {items: 6,}}})