$cy-spacer: ocyannumber("row-spacer", "rem");
$cy-font-size: 1rem;

@keyframes fade-up{
	from{ transform: translateY(30px); opacity: 0;}
	to{ transform: translateY(0); opacity: 1;}
}
@keyframes fade-in{
	from{ opacity: 0;}
	to{ opacity: 1;}
}
@keyframes overlay{
	from{ transform: scale(1.2); opacity: 0;}
	to{ transform: translateY(1); opacity: 1;}
}

.coyote-block-wrapper{
	padding-top: ($cy-spacer * 3);
	padding-bottom: ($cy-spacer * 3);
	@media screen and (max-width: 991px){
		padding-top: $cy-spacer;
		padding-bottom: $cy-spacer;
	}
}