.tabs{
	position: relative;
	@extend .coyote-block-wrapper;
	
	.image-bottom{
		@media screen and (min-width: 991px){
			position: absolute;
			bottom: 0;
			right: 0;
			height: 100%;
			width: 50vw;
			object-fit: cover;
			object-position: center;
			border-radius: 0;
		}
	}
	.tab-style-1{
		@media screen and (min-width: 991px){
			min-height: 400px;
		}
		.tab-content{
			padding-top: 1rem;
		}
		ul{
			position: relative;
			z-index: 3;
			&:before{
				content: "";
				position: absolute;
				bottom: 0px;
				left: 0;
				width: 100%;
				height: 1px;
				background: var(--counter-color);
				opacity: .1;
				z-index: -1;
			}
			button{
				background: transparent !important;
				padding-left: 0;
				padding-right: 0;
				margin-right: 1.5rem;
				font-size: ($cy-font-size * 1.5);
				font-weight: 600;
				border-bottom: 3px solid transparent;
				margin-bottom: -1px;
				padding-bottom: 1rem;
				border-radius: 0;
				&:not(.active){
					color: var(--counter-color);
				}
				&.active{
					color: var(--counter-color);
					border-bottom: 3px solid $primary;
				}
			}
		}
	}
}