{% load static %}
{# Default compiled Coyote stylesheet.
   Source SCSS entrypoint: static/coyote/base.scss.
   Hosts may intentionally override this partial or rebuild
   static/coyote/css/base.css from the same SCSS source using the
   MandelBlogStack django-libsass + oxyan theme Sass function path. #}
<link rel="stylesheet" href="{% static 'coyote/css/base.css' %}">
