# Generated by Django 5.2.3 on 2025-10-01 09:31

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("coyote", "0024_remove_coyotecontactpage_page_ptr_and_more"),
        ("ocyan_plugin_wagtail", "0029_alter_abstractbasepage_canonical_url"),
    ]

    operations = [
        migrations.SeparateDatabaseAndState(
            database_operations=[],
            state_operations=[
                migrations.RemoveField(
                    model_name="coyotecontactpage",
                    name="page_ptr",
                ),
                migrations.RemoveField(
                    model_name="coyotecontactpage",
                    name="search_image",
                ),
                migrations.RemoveField(
                    model_name="coyotehomepage",
                    name="page_ptr",
                ),
                migrations.RemoveField(
                    model_name="coyotehomepage",
                    name="search_image",
                ),
                migrations.AlterField(
                    model_name="coyotecontactpage",
                    name="abstractbasepage_ptr",
                    field=models.OneToOneField(
                        auto_created=True,
                        default=None,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to="ocyan_plugin_wagtail.abstractbasepage",
                    ),
                    preserve_default=False,
                ),
                migrations.AlterField(
                    model_name="coyotehomepage",
                    name="abstractbasepage_ptr",
                    field=models.OneToOneField(
                        auto_created=True,
                        default=None,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to="ocyan_plugin_wagtail.abstractbasepage",
                    ),
                    preserve_default=False,
                ),
            ],
        )
    ]
