.content-wrapper{
	position: relative;
	.image-left{
		@media screen and (min-width: 991px){
			position: absolute;
			top: 0;
			left: 0;
			width: 50vw;
			height: 100%;
			object-fit: cover;
			border-top-left-radius: 0;
			border-bottom-left-radius: 0;
		}
		@media screen and (max-width: 991px){
			width: 100%;
			height: auto;
		}
	}
	.content-image-text{
		padding-top: ($cy-spacer * 3);
		padding-bottom: ($cy-spacer * 3);
		padding-left: ($cy-spacer * 3);
		h2{
			font-weight: 700;
			line-height: 1.2em;
		}
		p{
			color: #526e6d;
			max-width: 500px;
		}
		@media screen and (max-width: 991px){
			padding: ($cy-spacer * 1);
			top: 0;
		}
		.btn-primary{
			border-radius: ($cy-spacer * 0.25);
		}
	}
}