# Generated by Django 5.2.3 on 2026-06-30 23:07

import ocyan.plugin.coyote.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("coyote", "0025_remove_coyotecontactpage_page_ptr_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="coyotecontactpage",
            name="content",
            field=ocyan.plugin.coyote.fields.CoyoteStreamField(
                (), blank=True, verbose_name="Content"
            ),
        ),
        migrations.AlterField(
            model_name="coyotehomepage",
            name="content",
            field=ocyan.plugin.coyote.fields.CoyoteStreamField(
                (), blank=True, verbose_name="Content"
            ),
        ),
    ]
