from wagtail import blocks

from .content import (
    BootstrapTabBlock,
    CounterAttribute,
    CoyoteAccordionAllBlock,
    CoyoteAccordionBlock,
    CoyoteCenterText,
    CoyoteIconBlock,
    CoyoteIconsWithText,
    CoyoteImageWithText,
    CoyoteLogos,
    CoyotePersonBlock,
    CoyotePersonListBlock,
    CoyoteQuoteBlock,
    CoyoteQuotesBlock,
    CoyoteTabsBlock,
    CoyoteTextListBlock,
)
from .footer import CoyoteCallToAction
from .header import (
    CoyoteCHeaderImages,
    CoyoteContent,
    CoyoteImages,
    CoyoteVideo,
)


class CoyoteDummyBlock(blocks.StaticBlock):
    pass


__all__ = [
    "BootstrapTabBlock",
    "CounterAttribute",
    "CoyoteAccordionAllBlock",
    "CoyoteAccordionBlock",
    "CoyoteCHeaderImages",
    "CoyoteCallToAction",
    "CoyoteCenterText",
    "CoyoteContent",
    "CoyoteDummyBlock",
    "CoyoteIconBlock",
    "CoyoteIconsWithText",
    "CoyoteImageWithText",
    "CoyoteImages",
    "CoyoteLogos",
    "CoyotePersonBlock",
    "CoyotePersonListBlock",
    "CoyoteQuoteBlock",
    "CoyoteQuotesBlock",
    "CoyoteTabsBlock",
    "CoyoteTextListBlock",
    "CoyoteVideo",
]
