# -*- coding: utf-8 -*-
default_app_config = "ocyan.plugin.coyote.apps.OcyanPluginCoyoteAppConfig"

__all__ = ["CoyoteConfig"]


def __getattr__(name):
    if name == "CoyoteConfig":
        from .entrypoint import CoyoteConfig

        return CoyoteConfig
    raise AttributeError(f"module {__name__!r} has no attribute {name!r}")
