COYOTE_COLOR_CHOICES = [
    ("primary", "Primary"),
    ("secondary", "Secondary"),
    ("light", "Light"),
    ("dark", "Dark"),
    ("outline-primary", "Primary border"),
    ("outline-secondary", "Secondary border"),
    ("outline-light", "Light border"),
    ("outline-dark", "Dark border"),
]
