.fontpanel>.w-panel__content>.w-field-row {
    grid-template-columns: 1.25fr .75fr 1.25fr .75fr;
}

.h1, .h2, .h3, .h4, .h5, .h6, h1, h2, h3, h4, h5, h6 {
    font-weight: unset;
    line-height: 1;
    margin: 1rem 0;
}
h1 { font-size: 2.00rem; }
h2 { font-size: 1.74rem; }
h3 { font-size: 1.52rem; }
h4 { font-size: 1.32rem; }
h5 { font-size: 1.15rem; }
h6 { font-size: 1.00rem; }
p { font-size: 1.00rem; }
.fontpanel select {
    width: 100%;
    line-height: unset!important;
}
.select2-search__field {
    outline: unset!important;
}

.select2-container--bootstrap-5 .select2-dropdown .select2-results__options .select2-results__option {
    color: var(--w-color-text-context)!important;
}

.select2-container--bootstrap-5 .select2-dropdown .select2-results__options .select2-results__option.select2-results__option--selected, .select2-container--bootstrap-5 .select2-dropdown .select2-results__options .select2-results__option[aria-selected=true]:not(.select2-results__option--highlighted),
.select2-container--bootstrap-5 .select2-dropdown .select2-results__options .select2-results__option.select2-results__option--highlighted {
    background-color: var(--w-color-black-5);
}


.select2-container--bootstrap-5.select2-container--open.select2-container--below .select2-selection,
.select2-container--bootstrap-5 .select2-dropdown .select2-search .select2-search__field,
.select2-container--bootstrap-5 .select2-selection--single,
.select2-container--bootstrap-5 .select2-dropdown {
    border: 1px solid var(--w-color-border-field-default) !important;
}

.select2-container--bootstrap-5.select2-container--open.select2-container--below .select2-selection:hover,
.select2-container--bootstrap-5 .select2-dropdown .select2-search .select2-search__field:hover,
.select2-container--bootstrap-5 .select2-selection--single:hover,
.select2-container--bootstrap-5 .select2-dropdown:hover {
    border-color: var(--w-color-border-field-hover)!important;
}

.select2-container--bootstrap-5 .select2-dropdown .select2-search .select2-search__field:focus {
    box-shadow: unset !important;
}
.select2-container--bootstrap-5.select2-container--focus .select2-selection, .select2-container--bootstrap-5.select2-container--open .select2-selection {
    box-shadow: unset !important;
    outline: 3px solid var(--w-color-focus) !important;
}

.select2-container--bootstrap-5 .select2-selection--single {
    appearance: none;
    background-color: var(--w-color-surface-field);
    background-image: linear-gradient(45deg, #0000 50%, var(--w-color-text-label) 33%, var(--w-color-text-label) 66%, #0000 66%), linear-gradient(-45deg, #0000 50%, var(--w-color-text-label) 33%, var(--w-color-text-label) 66%, #0000 66%);
    background-position-x: calc(100% - 1.5rem), calc(100% - 1.125rem);
    background-position-y: 1.125rem, 1.125rem;
    background-repeat: no-repeat;
    background-size: .375rem .375rem, .375rem .375rem;
    border-radius: .3125rem;
    color: var(--w-color-text-context);
    font-size: 1.1875rem;
    font-weight: 400;
    max-width: 100%;
    min-height: 2.625rem;
    padding-inline-end: 2.625rem;
    padding-inline-start: 1.25rem;
}
.select2-container--bootstrap-5 .select2-selection--single .select2-selection__rendered {
    line-height: 1.6;
    color: var(--w-color-text-context);
}
