{% extends "layout.html" %}
{% load wagtailmetadata_tags wagtailcore_tags static ocyan_main %}

{% wagtail_site as current_site %}

{% block title %}{{self.get_meta_title}}{% if page.get_site.site_name %} - {{ page.get_site.site_name }}{% endif %}{% endblock title %}
{% block description %}{{self.get_meta_description}}{% endblock description %}

{% block extrahead %}
    {{ block.super }}
    {% meta_tags %}
	<link rel="canonical" href="{% if page.canonical_url %}{{ page.canonical_url }}{% else %}{% absolute_url request.path %}{% endif %}">
{% endblock %}

{% block content_wrapper %}
	<div class="coyote-outer {% if self.monochrome %}monochrome{% endif %}" id="main_content" tabindex="-1">
	{% block content %}
	{% endblock %}
	</div>
{% endblock %}

{% block styles %}
	{{block.super}}
	{% include "coyote/partials/styles/base_styles.html" %}
{% endblock %}

{% block extrascripts %}
{{block.super}}
<script type="text/javascript" src="{% static 'coyote/js/page_sliders.js' %}"></script>
{% endblock %}
