# -*- coding: utf-8 -*-
from pathlib import Path

from setuptools import find_packages, setup

install_requires: list = ["ocyan.core", "wagtail-roadrunner", "oxyan.themes"]

extras_require: dict = {
    "test": [
        "empty_testproject",
        "ocyan.plugin.testing",
        "pylint-django",
        "ruff",
        "vdt.versionplugin.wheel",
        "coverage",
    ]
}

PACKAGE_CLASSIFIERS = [
    "License :: Other/Proprietary License",
    "Framework :: Ocyan",
    "Environment :: Plugins",
]

setup(
    name="ocyan.plugin.coyote",
    version="0.3.1",
    url="https://git.mandelblog.com/mandel-plugins/ocyan.plugin.coyote",
    author="Mandel",
    author_email="info@mandelblog.com",
    description="Wagtail page, block, and styling plugin for Ocyan themes.",
    long_description=Path("README.md").read_text(encoding="utf-8"),
    long_description_content_type="text/markdown",
    packages=find_packages(),
    include_package_data=True,
    python_requires=">=3.6",
    install_requires=install_requires,
    classifiers=PACKAGE_CLASSIFIERS,
    extras_require=extras_require,
)
