.contact_form{
	@extend .coyote-block-wrapper;
	#contact-form{
		label{
			text-transform: uppercase;
			font-weight: 600;
		}
		input:not([type="submit"]), textarea{
			padding: .5rem 1rem;
		}
		textarea{
			max-height: 100px;
		}
		.form_field_wrapper{
			position: relative;
			// .form-group{
			// 	&:after{
			// 		content: ""attr(cite) !important;
			// 		display: inline-block;
			// 		position: absolute;
			// 		top: 0;
			// 		left: 0;
			// 	}
			// }
			.form-control{
				border-top: 0;
				border-left: 0;
				border-right: 0;
				padding-left: .5rem !important;
				box-shadow: unset;	
				&:placeholder-shown{

				}
			}
		}
		.form-group{
			margin-bottom: 2rem !important;
		}
	}
}