@import "../variables";
@import "image_with_text";
@import "persons";
@import "category_block";
@import "accordion";
@import "quotesblock";
@import "products";
@import "contact";
@import "centertext";
@import "textlist";
.fa-secondary{opacity:.4}

.coyote-slider{
	.tns-outer{
		button[data-action="stop"], button[data-action="start"], .tns-nav{
			display: none;
		}
		.tns-controls{
			transition: .5s ease;
			@media screen and (min-width: 991px){
				width: calc(100% + 6rem);
				margin-left: -3rem;
			}
		}
		&:not(:hover){
			.tns-controls{
				opacity: 0;
			}
		}
	}
}