{% load ocyan_thumbnail wagtailcore_tags styling_tags wagtailembeds_tags %}

<style type="text/css">
	header{
		position: absolute;
		top: 0;
		left: 0;
		width: 100%;
		background: transparent;
		z-index: 9999;
	}
	header .header-inner .menu-bar .nav-item .nav-link,
	header .header-inner .nav-icon{
		color: white;
	}
	header .navbar-brand{
		filter: brightness(0) invert(1);
	}
</style>
<section class="hero full-screen video {{ self.layout }}">
	{{self.auto_play|safe}}
	{% if self.overlay %}
	<span class="overlay"></span>
	{% endif %}
	<div class="container">
		<div class="row">
			<div class="hero-lead my-auto {% if self.center_text %} text-center mx-auto col-lg-8{% else %} col-lg-6{% endif %}">
				{{ self.body|richtext }}
				{% if self.buttons %}
				<div class="buttons-wrapper">
					{% for button in self.buttons %}
						{% include "coyote/blocks/partials/button.html" %}
					{% endfor %}
				</div>
				{% endif %}
			</div>
		</div>
	</div>
</section>
